package com.qmth.distributed.print.business.service;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.service.IService;
import com.qmth.distributed.print.business.bean.dto.FinalScoreDto;
import com.qmth.distributed.print.business.bean.result.FinalScoreResult;
import com.qmth.distributed.print.business.entity.TCFinalScore;
import org.springframework.web.multipart.MultipartFile;

import java.io.IOException;
import java.util.List;
import java.util.Map;

/**
 * <p>
 * 期末考试成绩表 服务类
 * </p>
 *
 * @author wangliang
 * @since 2024-02-18
 */
public interface TCFinalScoreService extends IService<TCFinalScore> {

    /**
     * 导入期末成绩excel
     */
    public Map<String, String> finalScoreExcelImport(MultipartFile file, Long examId, Long courseId, String paperNumber, Long teachCourseId) throws IOException;

    /**
     * 期末成绩列表（分页）
     */
    public IPage<TCFinalScore> finalScoreList(IPage<Map> iPage, Long examId, Long courseId, String paperNumber, Long teachCourseId);

    /**
     * 查找期末成绩分数图
     */
    public FinalScoreDto finalScoreScoreOverView(Long examId, Long courseId, String paperNumber, Long teachCourseId);

    /**
     * 查找期末成绩分数区间
     *
     * @param examId
     */
    public int getCountByScoreRange(Long examId, Long courseId, String paperNumber, Long teachCourseId, Double start, Double end);

    /**
     * 查找考生成绩
     */
    public List<FinalScoreResult> examStudentOverview(Long examId, Long courseId, String paperNumber, Long teachCourseId);

    /**
     * 同步期末成绩
     */
    public Map<String, String> finalScoreSync(Long examId, Long courseId, String paperNumber, Long teachCourseId) throws IOException;

    /**
     * 根据考试id/课程编码/试卷编码删除数据
     */
    public Boolean remove(Long examId, Long courseId, String paperNumber, Long teachCourseId);

    /**
     * 根据考试id/课程编码/试卷编码查询数据库数据
     */
    public List<TCFinalScore> queryFinalScore(Long examId, Long courseId, String paperNumber, Long teachCourseId);

    /**
     * 获取期末考试同步锁
     */
    public void getFinalScoreSyncLock(Long examId, Long courseId, String paperNumber, Long teachCourseId);

    /**
     * 获取期末考试导入锁
     */
    public void getFinalScoreImportLock(Long examId, Long courseId, String paperNumber, Long teachCourseId);
}
